@@ -58,6 +58,7 @@ my %never_delete = map { $_ => undef }
      22729, # according to CoreList this is 5.008004
      ##22739,22741, # Devel::Profile 1.05
      22841,22842, # Encode::IMAPUTF7
+     22861,22862, # fixes YAML::LibYAML 0.32
      23139, # according to CoreList this is 5.008005
      23390, # 5.008005 THREAD
      23470,23471, # DCOPPIT/Mail-Mbox-MessageParser-1.5000.tar.gz
@@ -70,10 +71,11 @@ my %never_delete = map { $_ => undef }
      24517,24518, # removed AvFLAGS
      24521,24522, # removed HvPMROOT
      24525,24529, # 26 removed xhv_eiter from XPVHV and 29 regained compilability
-     24541,24542, # Math::Pari
-     24556,24557, # Math::Pari after rafl's patch
+     # 24541,24542, # Math::Pari
+     # 24556,24557, # Math::Pari after rafl's patch
      24641, # according to CoreList this is 5.008007
      24659,24660, # Class::constr, Data::Structure::Util
+     24713,24714, # shared hash keys, manifested in AVIF/Tree-Trie-1.5
      24965,24966, # Safe::World but only of marginal importance because failure has changed
      25178,25179, # CharsetDetector 1.0
      25567,25568, # srezic-rx-problem
@@ -91,11 +93,13 @@ my %never_delete = map { $_ => undef }
      27040, # 5.008008 according to corelist
      27263,27264, # JSON 1.12
      27533,27534, # regexp recursion stuff/regression(rtperl#60034)
+     27648,27649, # Devel::Arena
      27704,27705, # Thread.pm emulation: Net::Daemon
      28358,28359, # encoding::source
      28867,28868, # Regexp::Optimizer 0.15
      28966, # 5.009004
      29025,29026, # DBIx::Class(?), Authen::Htpasswd
+     29278,29279, # Apache::Parselog 1.02
      29317,29318, # String::Multibyte
      30038,30039, # forks 0.27
      30487,30488, # Devel::Cover 0.61
@@ -116,23 +120,26 @@ my %never_delete = map { $_ => undef }
      32706,32707, # breaks Data::Alias, Devel::Declare, autobox
      32733,32734, # DROLSKY/Class-MOP-0.65-70; replace RVs with IVs
      32739,32740, # breaks YAML::LibYAML due to ORANGE regexps
-     32856,32857, # DCONWAY/Getopt-Euclid-v0.1.0.tar.gz know your enemy, this is hard to binarysearch, not the usual oneliner!
-     33017,33018, # RCLAMP/Devel-Caller-2.03.tar.gz, Coro 4.37
-     33021,33022, # DROLSKY/Devel-StackTrace-1.15.tar.gz, Devel-ebug-0.48
-     33027,33028, # ROBIN/Want-0.16.tar.gz
-     33029,33030, # ROBIN/PadWalker-1.6.tar.gz
-     33056,33057, # ROBIN/Want-0.16.tar.gz again
-     33071,33072, # PJCJ/Devel-Cover-0.63.tar.gz, ANDYA/Devel-LeakTrace-Fast-0.11.tar.gz
+     32856,32857, # DCONWAY/Getopt-Euclid-v0.1.0 know your enemy, this is hard to binarysearch, not the usual oneliner!
+     32953,32954, # Data-PostfixDeref-0.03
+     33017,33018, # RCLAMP/Devel-Caller-2.03, Coro 4.37
+     33021,33022, # DROLSKY/Devel-StackTrace-1.15, Devel-ebug-0.48
+     33027,33028, # ROBIN/Want-0.16
+     33029,33030, # ROBIN/PadWalker-1.6
+     33056,33057, # ROBIN/Want-0.16 again
+     33071,33072, # PJCJ/Devel-Cover-0.63, ANDYA/Devel-LeakTrace-Fast-0.11
      33085,33086, # PAR::Packer 0.978
      33087,33088, # OLAF/Net-DNS-0.62.tar.gz
      33709,33710, # PJCJ/Devel-Cover-0.64.tar.gz
      33871,33874, # DLAND/Regexp-Assemble-0.33.tar.gz
+     34481,34482, # Perl6::Say broke on this makemaker
      # current smoker
      # 24329, # 5.8.6
-     26727, # 5.8.7
+     # 26727, # before 5.8.8, not acceptable, bug between 26696 and 26894
      27512, # 5.8.8
      34437, # 5.10.1 tobe
-     34468, # 5.8.9 tobe
+     35054, # ~5.8.9
+     39999, # need a new plan for those
     );
 ENDLESS: while () {
   my @dirs;
